approx.Z: Interpolating in smoothing spline Z-matrix columns
Description
Function to interpolate the \(Z\)-matrix for LME smoothing spline fits
from one set of values of the time covariate to another.
Usage
approx.Z(Z, oldtimes, newtimes)
Value
A matrix corresponding to an interpolated spline matrix. Can be used
with smspline() for fitting LME splines with random effects
corresponding to a different set of values of the time covariate
than those represented in the data, or as part of the `newdata' argument
prediction from an existing model, to obtain predictions at points
not represented in the data using predict.lme().
Arguments
Z
\(Z\)-matrix with rows corresponding to the sorted unique
values of the time covariate
oldtimes
original (sorted) values for time covariate,
corresponding to the rows of \(Z\)