Learn R Programming

lmeSplines (version 1.1.20)

smSplineEx1: Simulated Data for Smoothing Spline Curve Fitting

Description

Simulated dataset to demonstrate smoothing spline curve fitting with smspline and lme. The data consists of 100 observations simulated around the curve \(y = 10 - 6 \exp(-4t/100)\) with independent normal random errors (standard deviation = 1).

Simulated dataset to demonstrate smoothing spline curve fitting with smspline and lme. The data consists of 100 observations simulated around the curve \(y = 10 - 6 \exp(-4t/100)\) with independent normal random errors (standard deviation = 1).

Usage

smSplineEx1

smSplineEx1

Arguments

Format

A data frame with 100 rows and 3 variables:

time

Time covariate.

y

Simulated response values.

y.true

True response values.

A data frame with 100 rows and 3 variables:

time

Time covariate.

y

Simulated response values.

y.true

True response values.

Examples

Run this code
data(smSplineEx1)
str(smSplineEx1)

data(smSplineEx1)
str(smSplineEx1)
plot(smSplineEx1$time, smSplineEx1$y, main = "Simulated Data", xlab = "Time", ylab = "y")
lines(smSplineEx1$time, smSplineEx1$y.true, col = "blue")

Run the code above in your browser using DataLab